@@ -170,7 +170,7 @@ convert.epipara.to.delappara = function(
 #'
 #' @note
 #' Only the PDF of individual reproduction number (i.e., \code{d_reproductiondistn()}) was created here (without cumulative distribution, quantile, or random variable generating functions).
-#' The function \code{d_reproductiondistn()} was used mainly for data visualization purpose,
+#' The function \code{d_reproductiondistn()} was used mainly for data visualization purpose (rather than using for analysis),
 #' because the distribution of individual reproduction number was not explicitly used in model fitting to the disease contact tracing data.
 #'
 #' When \code{offspring.type = "P"}, individual reproduction number follows a *Dirac delta* distribution, which is difficult to return any value, or visualize the PDF, because of the nature of this pulse function.
@@ -250,7 +250,7 @@ d_reproductiondistn = function(
 #' By default, \code{offspring.type = 'D'}.
 #' @param is.log A logical variable, under which probability would be taken natural logarithm, if \code{is.log = TRUE}.
 #' By default, \code{is.log = FALSE}.
-#' @param lower.tail A logical variable, under which the probability is cumulative distribution function (CDF, i.e., *P(X <= x)*), if \code{is.log = TRUE}, and otherwise, 1 - CDF (i.e., *P(X > x)*).
+#' @param lower.tail A logical variable, under which the probability is cumulative distribution function (CDF, i.e., *P(X <= x)*), if \code{lower.tail = TRUE}, and otherwise, 1 - CDF (i.e., *P(X > x)*).
 #' By default, \code{lower.tail = TRUE}.
 #'
 #' @details
@@ -268,7 +268,7 @@ d_reproductiondistn = function(
 #'   \item{\code{d_offspringdistn()}}{ is the *probability mass function* (PMF), and it returns value of probability (i.e., ranging from 0 to 1); }
 #'   \item{\code{p_offspringdistn()}}{ is the *cumulative distribution function* (CDF), and it returns value of probability (i.e., ranging from 0 to 1); }
 #'   \item{\code{q_offspringdistn()}}{ is the *quantile function*, and it returns value of quantile (non-negative integer); and }
-#'   \item{\code{r_offspringdistn()}}{ is the *random variable generating function*, and it generates a set of random variables (non-negative integers) with size given in \code{n}. }
+#'   \item{\code{r_offspringdistn()}}{ is the *random variable generating function*, and it generates a set of \code{n} random variables (non-negative integers). }
 #' }
 #'
 #' @import Delaporte
@@ -444,7 +444,7 @@ r_offspringdistn = function(
 #' By default, \code{offspring.type = 'D'}.
 #' @param is.log A logical variable, under which probability would be taken natural logarithm, if \code{is.log = TRUE}.
 #' By default, \code{is.log = FALSE}.
-#' @param lower.tail A logical variable, under which the probability is cumulative distribution function (CDF, i.e., *P(X <= x)*), if \code{is.log = TRUE}, and otherwise, 1 - CDF (i.e., *P(X > x)*).
+#' @param lower.tail A logical variable, under which the probability is cumulative distribution function (CDF, i.e., *P(X <= x)*), if \code{lower.tail = TRUE}, and otherwise, 1 - CDF (i.e., *P(X > x)*).
 #' By default, \code{lower.tail = TRUE}.
 #'
 #' @details
@@ -454,7 +454,7 @@ r_offspringdistn = function(
 #'
 #' Function \code{q_nextgenclusterdistn()} returns a value such that there is a probability of \code{p} for having a next-generation case cluster with size less than or equal to, or larger than this value (depending on the value of \code{lower.tail}) generated by \code{seed.size} index cases, where (\code{seed.size}) is given.
 #'
-#' Function \code{r_nextgenclusterdistn()} returns a set of random variables of next-generation cluster size given in \code{n}, given (\code{seed.size}).
+#' Function \code{r_nextgenclusterdistn()} returns a set of random variables of \code{n} next-generation cluster size, given (\code{seed.size}).
 #'
 #'
 #' @return
@@ -463,7 +463,7 @@ r_offspringdistn = function(
 #'   \item{\code{d_nextgenclusterdistn()}}{ is the *probability mass function* (PMF), and it returns value of probability (i.e., ranging from 0 to 1); }
 #'   \item{\code{p_nextgenclusterdistn()}}{ is the *cumulative distribution function* (CDF), and it returns value of probability (i.e., ranging from 0 to 1); }
 #'   \item{\code{q_nextgenclusterdistn()}}{ is the *quantile function*, and it returns value of quantile (positive integer); and }
-#'   \item{\code{r_nextgenclusterdistn()}}{ is the *random variable generating function*, and it generates a set of random variables (positive integers) with size given in \code{n}. }
+#'   \item{\code{r_nextgenclusterdistn()}}{ is the *random variable generating function*, and it generates a set of \code{n} random variables (positive integers). }
 #' }
 #'
 #' @import Delaporte
@@ -636,7 +636,7 @@ r_nextgenclusterdistn = function(
 #' By default, \code{offspring.type = 'D'}.
 #' @param is.log A logical variable, under which probability would be taken natural logarithm, if \code{is.log = TRUE}.
 #' By default, \code{is.log = FALSE}.
-#' @param lower.tail A logical variable, under which the probability is cumulative distribution function (CDF, i.e., *P(X <= x)*), if \code{is.log = TRUE}, and otherwise, 1 - CDF (i.e., *P(X > x)*).
+#' @param lower.tail A logical variable, under which the probability is cumulative distribution function (CDF, i.e., *P(X <= x)*), if \code{lower.tail = TRUE}, and otherwise, 1 - CDF (i.e., *P(X > x)*).
 #' By default, \code{lower.tail = TRUE}.
 #' @param upr.limit A positive integer.
 #' If the result final outbreak size is larger than \code{upr.limit}, the returned value will be set as "\code{> upr.limit}".
@@ -650,7 +650,7 @@ r_nextgenclusterdistn = function(
 #'   \item{\code{d_outbreakdistn()}}{ is the *probability mass function* (PMF), and it returns value of probability (i.e., ranging from 0 to 1); }
 #'   \item{\code{p_outbreakdistn()}}{ is the *cumulative distribution function* (CDF), and it returns value of probability (i.e., ranging from 0 to 1); }
 #'   \item{\code{q_outbreakdistn()}}{ is the *quantile function*, and it returns value of quantile (positive integer); and }
-#'   \item{\code{r_outbreakdistn()}}{ is the *random variable generating function*, and it generates a set of random variables (positive integers) with size given in \code{n}. }
+#'   \item{\code{r_outbreakdistn()}}{ is the *random variable generating function*, and it generates a set of \code{n} random variables (positive integers). }
 #' }
 #'
 #' Specially, due to the computational consumption, an upper limit was set for the functions \code{q_outbreakdistn()} and \code{r_outbreakdistn()},
@@ -663,7 +663,7 @@ r_nextgenclusterdistn = function(
 #'
 #' Function \code{q_outbreakdistn()} returns a value such that there is a probability of \code{p} for having a final outbreak size less than or equal to, or larger than this value (depending on the value of \code{lower.tail}) generated by \code{seed.size} index cases, where (\code{seed.size}) is given.
 #'
-#' Function \code{r_outbreakdistn()} returns a set of random variables of final outbreak size given in \code{n}, given (\code{seed.size}).
+#' Function \code{r_outbreakdistn()} returns a set of \code{n} random variables of final outbreak size, given (\code{seed.size}).
 #'
 #'
 #' @import Delaporte
@@ -1046,7 +1046,10 @@ tailoffspringQ = function(
   })) / epi.para$mean
   #    plot(c(0,prop.sourcecase.array,1), c(0,prop.secondcase.array,1))#, type = 'l'
 
-  return(prop.secondcase.array[match(P, prop.sourcecase.array)])
+  output.array = prop.secondcase.array[match(P, prop.sourcecase.array)]#
+  output.array = ifelse(P == 0, 0, output.array); output.array = ifelse(P == 1, 1, output.array)
+
+  return(output.array)
 }
 
 #'
@@ -1082,7 +1085,10 @@ mostinfectiousP = function(
     sol.index.prop.array = c(sol.index.prop.array, sol.index.prop)
   }
 
-  return(c(sol.index.prop.array))
+  output.array = c(sol.index.prop.array)#
+  output.array = ifelse(Q == 0, 0, output.array); output.array = ifelse(Q == 1, 1, output.array)
+
+  return(output.array)
 }
 
 
